/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.discovery.base.commons;

import org.apache.sling.api.resource.ResourceResolverFactory;
import org.apache.sling.commons.scheduler.Scheduler;
import org.apache.sling.discovery.base.connectors.BaseConfig;
import org.apache.sling.discovery.base.connectors.announcement.AnnouncementRegistry;
import org.apache.sling.discovery.base.connectors.ping.ConnectorRegistry;

public class DummyDiscoveryService extends BaseDiscoveryService {

    private final ClusterViewService clusterViewService;
    private final AnnouncementRegistry topologyRegistry;

    public DummyDiscoveryService(String slingId,
            ClusterViewService clusterViewService,
            AnnouncementRegistry topologyRegistry,
            ResourceResolverFactory resourceResolverFactory, BaseConfig config, 
            ConnectorRegistry connectorRegistry, Scheduler scheduler) {
        this.clusterViewService = clusterViewService;
        this.topologyRegistry = topologyRegistry;
    }
    
    @Override
    protected ClusterViewService getClusterViewService() {
        return clusterViewService;
    }

    @Override
    protected AnnouncementRegistry getAnnouncementRegistry() {
        return topologyRegistry;
    }

    @Override
    protected void handleIsolatedFromTopology() {
        throw new IllegalStateException("handleIsolatedFromTopology not yet impl");
    }
    
}
